translate.misc.file_discovery

Package translate :: Package misc :: Module file_discovery |
[hide private]
[frames] | no frames]

# Module file_discovery

source code

Functions | [hide private]
get_abs_data_filename(path_parts, basedirs=None) Get the absolute path to the given file- or directory name in the current running application's data directory. | source code

Variables | [hide private]
| __package__ = ``'``translate.misc``'``

Imports: sys, os

Function Details | [hide private]

### get_abs_data_filename(path_parts, basedirs=None) | source code
Get the absolute path to the given file- or directory name in the current running application's data directory. Parameters: `path_parts` (list) - The path parts that can be joined by os.path.join().